"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InjectMetric = InjectMetric;
const common_1 = require("@nestjs/common");
const metrics_1 = require("./metrics");
/**
 * Used to inject the registered metric via the given token
 *
 * @public
 *
 * @example
 * Assuming you have registered a metric with the name `metric_name`, you would inject it
 * like so:
 * ```
 * import { Injectable } from "@nestjs/common";
 * import { Counter } from "prom-client";
 * import { InjectMetric } from "@willsoto/nestjs-prometheus";
 *
 * @Injectable()
 * export class Service {
 *   constructor(@InjectMetric("metric_name") public counter: Counter<string>) {}
 * }
 * ```
 */
function InjectMetric(name) {
    return (0, common_1.Inject)((0, metrics_1.getToken)(name));
}
//# sourceMappingURL=injector.js.map